@@ -77,6 +77,7 @@ sub requires_perl {
 }
 
 sub meta_merge {
+    my ( undef, @extra ) = @_;
     return {
 	'meta-spec'	=> {
 	    version	=> 2,
@@ -96,10 +97,22 @@ sub meta_merge {
 		url	=> 'git://github.com/trwyant/perl-Astro-App-Satpass2.git',
 		web	=> 'https://github.com/trwyant/perl-Astro-App-Satpass2',
 	    },
-	}
+	},
+	@extra,
     };
 }
 
+sub provides {
+    -d 'lib'
+	or return;
+    local $@ = undef;
+    my $provides = eval {
+	require Module::Metadata;
+	Module::Metadata->provides( version => 2, dir => 'lib' );
+    } or return;
+    return ( provides => $provides );
+}
+
 
 1;
 
@@ -107,7 +120,7 @@ __END__
 
 =head1 NAME
 
-My::Module::Meta - Information needed to build My::Module
+My::Module::Meta - Information needed to build Astro::App::Satpass2
 
 =head1 SYNOPSIS
 
@@ -166,6 +179,18 @@ has to be provided by making use of the builder's C<meta_merge>
 functionality. This includes the C<dynamic_config>, C<no_index> and
 C<resources> data.
 
+Any arguments will be appended to the generated array.
+
+=head2 provides
+
+ use YAML;
+ print Dump( [ $meta->provides() ] );
+
+This method attempts to load L<Module::Metadata|Module::Metadata>. If
+this succeeds, it returns a C<provides> entry suitable for inclusion in
+L<meta_merge()|/meta_merge> data (i.e. C<'provides'> followed by a hash
+reference). If it can not load the required module, it returns nothing.
+
 =head2 requires
 
  use YAML;
